package Hawat::Controller::Accesslog;
use strict;
use warnings;
use Moose;
use namespace::autoclean;

use Data::Dumper;
use Mentat::Core qw(:c_hawat);

#-------------------------------------------------------------------------------
# Initialization section
#-------------------------------------------------------------------------------

BEGIN { extends 'Hawat::Controller::Secure'; }

__PACKAGE__->config(
    class       => 'Hawat::Controller::Accesslog',
    constructor => 'new',
);

=head1 NAME

Hawat::Controller::Accesslog - Catalyst controller for access log management

=head1 DESCRIPTION

Catalyst controller for handling actions related to access log management.

=head1 ACTIONS

=cut

#-------------------------------------------------------------------------------
# Implementation section
#-------------------------------------------------------------------------------

=head2 index

Default controller action, redirects to the 'list' action

=cut

sub index :Path :Args(0) {
    my ( $self, $c ) = @_;
    $c->response->redirect($c->uri_for($self->action_for('list')));
}

=head2 list

View the list of all accesslogs stored in the database

=cut

sub list :Local :Args(0) {
    my ($self, $c) = @_;

    # Store the back link to this request
    $c->session->{backlink} = $c->req->uri;

    # Configure and forward to '/dbitem/find' action
    my $conf = $self->_dbicnf(
        #limit  => $c->cfg('result_limit'),
        sortby => 'ts',
        sort   => 'desc',
        dfrom  => $c->time_before('1week', 1),
    );
    $c->forward(HAWAT_DBI_FIND, [$conf]);

    my $fr = $c->stash->{accesslogs};
    $c->stash(frs => $c->model('Accesslogs')->calculate_frs($fr));

    # Choose the template to fill
    $c->stash(template => 'accesslog/list.html.tt');
}

# _dbicnf(%)
#
#  Usage     :
#  Purpose   :
#  Arguments :
#  Returns   :
#  Throws    : Dies, if not invoked on object instance

sub _dbicnf(%)
{
    my ($self, %cnf_a) = @_;
    my $cnf = {
            controller => 'Accesslog',
            model      => HAWAT_MODEL_ACCESSLOGS(),
            items      => 'Accesslogs',
            item       => 'Accesslog',
            menu       => 'admin',
        };
    foreach my $k (keys %cnf_a) {
        $cnf->{$k} = $cnf_a{$k};
    }
    return $cnf;
}

=head1 AUTHOR

 Jan Mach
 Cesnet, z.s.p.o
 jan.mach@cesnet.cz
 http://www.cesnet.cz

=head1 LICENSE

This library is free software. You can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

__PACKAGE__->meta->make_immutable;

1;
