package Hawat::Model::Admin;
use strict;
use warnings;
use Moose;
use namespace::autoclean;

use Carp;
use Scalar::Util 'blessed';
use Time::HiRes qw (time);
use HTML::Entities;

use Data::Dumper;
use Mentat::Core qw(:c_hawat);
use Value::Convertor;
use Mentat::System;

#-------------------------------------------------------------------------------
# Initialization section
#-------------------------------------------------------------------------------

# Define meaningful default configuration values
use constant DFLT_FLAG_DEVEL => 0;

BEGIN { extends 'Catalyst::Model::Adaptor'; }

__PACKAGE__->config(
    class           => 'Hawat::Model::Devel',
    constructor     => 'new',
    devel           => 0,
    database_name   => 'mentat',
    collection_name => 'alerts',
    run_dir         => '/var/mentat/run',
);
has "devel"           => (is => 'ro', isa => 'Bool', required => 1);
has "database_name"   => (is => 'ro', isa => 'Str',  required => 1);
has "collection_name" => (is => 'ro', isa => 'Str',  required => 1);
has "run_dir"         => (is => 'ro', isa => 'Str',  required => 1);

#-------------------------------------------------------------------------------
# Implementation section
#-------------------------------------------------------------------------------

sub get_run_logs($)
{
    my $self = shift;
    my $rewrite = shift;
    confess "Instance method not invoked on object instance" unless blessed($self);

    my $runlogs = Mentat::System->runlogs_load($self->run_dir);
    return $runlogs;
}

#-------------------------------------------------------------------------------

# BUILD()
#
#  Purpose : Perform additional instance setup after the object is created
#  Comment : Callback method, see Moose::Manual::Construction(3) for details

sub BUILD {
    my $self = shift;
}

# COMPONENT
#
#  Purpose : Perform additional instance setup after the object is created
#  Comment : Callback method, see Catalyst::Component(3) for details
#
#  FIXME: For some reason config merging does not work without this code present
#         in the package!!!

sub COMPONENT {
    my ($class, $app, $args) = @_;
    $args = $class->merge_config_hashes($class->config, $args);
    #use Data::Dumper;
    #$app->log->debug("X $class: " . Dumper($class->config));
    #$app->log->debug("Y args  : " . Dumper($args));
    #$app->log->debug("Z $app  : " . Dumper($app->config));
    #$app->log->debug("MERGE XY: " . Dumper($args));
    return $class->new($app, $args);
}

1;
